SplashPayAuthenticationException class

Authentication failure (invalid API credentials).

Inheritance

Constructors

SplashPayAuthenticationException({required String message, String? code, int? statusCode, dynamic data})
Creates a SplashPayAuthenticationException.
const

Properties

code String?
Machine-readable SplashPay error code when available.
finalinherited
data → dynamic
Raw error payload for debugging.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
HTTP status code when available.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited