SplashPayException class

Base exception for all SplashPay SDK errors.

Implemented types
Implementers

Constructors

SplashPayException({required String message, String? code, int? statusCode, dynamic data})
Creates a SplashPayException.
const

Properties

code String?
Machine-readable SplashPay error code when available.
final
data → dynamic
Raw error payload for debugging.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
HTTP status code when available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited