PaymentResponse class
SplashPay API response wrapper for payment operations.
Constructors
-
PaymentResponse({required bool success, String? apiStatus, String? code, String? message, PaymentData? data, List meta = const [], String? requestId, Map<
String, dynamic> ? raw}) -
Creates PaymentResponse.
const
-
PaymentResponse.fromJson(Map<
String, dynamic> json) -
Parses a SplashPay JSON response body.
factory
Properties
- apiStatus → String?
-
Top-level API status (
successorerror).final - code → String?
-
Machine-readable response code (e.g.
PAYMENT_INITIATED).final - data → PaymentData?
-
Typed payment data when present.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
Human-readable response message.
final
- meta → List
-
Additional response metadata.
final
- paymentStatus → PaymentStatus
-
Parsed payment transaction status from data.
no setter
- providerReference → String?
-
Provider reference from data when available.
no setter
-
raw
→ Map<
String, dynamic> ? -
Full raw JSON response for debugging.
final
- reference → String?
-
Payment reference from data when available.
no setter
- requestId → String?
-
Unique request identifier for support.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
Whether the API request succeeded (
status == success).final - transactionId → String?
-
Transaction ID alias for providerReference.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited