SplashPayConfig class
Configuration for the SplashPay HTTP client.
Constructors
- SplashPayConfig({required String apiKey, required String apiSecret, SplashPayEnvironment environment = SplashPayEnvironment.production, String baseUrl = productionBaseUrl, Duration connectTimeout = const Duration(seconds: 30), Duration receiveTimeout = const Duration(seconds: 30), Duration sendTimeout = const Duration(seconds: 30), void logger(String message)?})
-
Creates SplashPay client configuration.
const
Properties
- apiKey → String
-
Merchant API key (
X-API-KEY).final - apiSecret → String
-
Merchant API secret (
X-API-SECRET).final - baseUrl → String
-
API base URL. Defaults to the documented production URL.
final
- connectTimeout → Duration
-
Connection timeout.
final
- environment → SplashPayEnvironment
-
Target environment (credential type).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → void Function(String message)?
-
Optional logging callback. Never log secrets or sensitive customer data.
final
- receiveTimeout → Duration
-
Receive timeout.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendTimeout → Duration
-
Send timeout.
final
Methods
-
authHeaders(
{String? idempotencyKey}) → Map< String, String> - Standard authentication and content headers for SplashPay requests.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- productionBaseUrl → const String
- Documented SplashPay API base URL.